==> jc-1.4.0.tar.gz: soot/tagkit/SourcePositionTag.c <==
// public class soot.tagkit.SourcePositionTag

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 4f112a0e13b029d9 soot_tagkit_PositionTag
// @dep_class 50f5695cb4eac404 soot_tagkit_SourcePositionTag
// @dep_class 145f73eb6621ab3a soot_tagkit_Tag

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header soot_tagkit_SourcePositionTag
// @dep_header soot_tagkit_Tag

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "soot/tagkit/SourcePositionTag.h"
#include "soot/tagkit/Tag.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(int, int)
//

static _jc_linenum _jc_soot_tagkit_SourcePositionTag$linenum_table$_init$02b806c1c13eed5e[];

static const unsigned char _jc_soot_tagkit_SourcePositionTag$param_ptypes$_init$02b806c1c13eed5e[] = { 
_JC_TYPE_INT, _JC_TYPE_INT, _JC_TYPE_VOID };

static _jc_type *const _jc_soot_tagkit_SourcePositionTag$param_types$_init$02b806c1c13eed5e[] = {
	&_jc_int$prim$type,
	&_jc_int$prim$type
};

_jc_method _jc_soot_tagkit_SourcePositionTag$method_info$_init$02b806c1c13eed5e = {
	.name=			"<init>",
	.signature=		"(II)V",
	.class=			&_jc_soot_tagkit_SourcePositionTag$type,
	.param_types=		&_jc_soot_tagkit_SourcePositionTag$param_types$_init$02b806c1c13eed5e,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_tagkit_SourcePositionTag$param_ptypes$_init$02b806c1c13eed5e,
	.signature_hash=	_JC_JLONG(0x2b806c1c13eed5e),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_tagkit_SourcePositionTag$method$_init$02b806c1c13eed5e,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_tagkit_SourcePositionTag$linenum_table$_init$02b806c1c13eed5e
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_tagkit_SourcePositionTag, _init$02b806c1c13eed5e);

void
_jc_soot_tagkit_SourcePositionTag$method$_init$02b806c1c13eed5e(_jc_env *const env, _jc_soot_tagkit_SourcePositionTag$object *this, jint param0, jint param1)
{
	jint i0;
	jint i1;
	struct _jc_soot_tagkit_SourcePositionTag$object *r0;

	r0 = this;
	i0 = param0;
	i1 = param1;
	_JC_PRIM_FIELD(env, r0, soot_tagkit_PositionTag, startOffset) = i0;
	_JC_PRIM_FIELD(env, r0, soot_tagkit_PositionTag, endOffset) = i1;
	_JC_LINE_NUMBER(6);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String getName()
//

static _jc_linenum _jc_soot_tagkit_SourcePositionTag$linenum_table$getName$bec186f2ce7e1882[];

static const unsigned char _jc_soot_tagkit_SourcePositionTag$param_ptypes$getName$bec186f2ce7e1882[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_tagkit_SourcePositionTag$method_info$getName$bec186f2ce7e1882 = {
	.name=			"getName",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_soot_tagkit_SourcePositionTag$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_soot_tagkit_SourcePositionTag$param_ptypes$getName$bec186f2ce7e1882,
	.signature_hash=	_JC_JLONG(0xbec186f2ce7e1882),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_tagkit_SourcePositionTag$method$getName$bec186f2ce7e1882,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_tagkit_SourcePositionTag$vtable, soot_tagkit_SourcePositionTag.getName$bec186f2ce7e1882) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_tagkit_SourcePositionTag$linenum_table$getName$bec186f2ce7e1882
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_tagkit_SourcePositionTag, getName$bec186f2ce7e1882);

_jc_java_lang_String$object *
_jc_soot_tagkit_SourcePositionTag$method$getName$bec186f2ce7e1882(_jc_env *const env, _jc_soot_tagkit_SourcePositionTag$object *this)
{
	struct _jc_soot_tagkit_SourcePositionTag$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(10);				// 0
	return _JC_STRING(env, "SourcePositionTag");
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_tagkit_SourcePositionTag$methods[] = {
	&_jc_soot_tagkit_SourcePositionTag$method_info$_init$02b806c1c13eed5e,
	&_jc_soot_tagkit_SourcePositionTag$method_info$getName$bec186f2ce7e1882
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_soot_tagkit_SourcePositionTag$imethod_hash_bucket_2[] = {
	&_jc_soot_tagkit_SourcePositionTag$method_info$getName$bec186f2ce7e1882,
	_JC_NULL
};
static _jc_method *_jc_soot_tagkit_SourcePositionTag$imethod_hash_bucket_41[] = {
	&_jc_soot_tagkit_PositionTag$method_info$getValue$824c7561d2f47329,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_soot_tagkit_SourcePositionTag$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[2]=	_jc_soot_tagkit_SourcePositionTag$imethod_hash_bucket_2,
	[41]=	_jc_soot_tagkit_SourcePositionTag$imethod_hash_bucket_41
};

// Interface "quick" lookup hash table
static const void *_jc_soot_tagkit_SourcePositionTag$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[2]=	&_jc_soot_tagkit_SourcePositionTag$method$getName$bec186f2ce7e1882,
	[41]=	&_jc_soot_tagkit_PositionTag$method$getValue$824c7561d2f47329
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_tagkit_SourcePositionTag$instanceof_hash_bucket_4[] = {
	&_jc_soot_tagkit_SourcePositionTag$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_SourcePositionTag$instanceof_hash_bucket_58[] = {
	&_jc_soot_tagkit_Tag$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_SourcePositionTag$instanceof_hash_bucket_89[] = {
	&_jc_soot_tagkit_PositionTag$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_SourcePositionTag$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_tagkit_SourcePositionTag$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[4]=	_jc_soot_tagkit_SourcePositionTag$instanceof_hash_bucket_4,
	[58]=	_jc_soot_tagkit_SourcePositionTag$instanceof_hash_bucket_58,
	[89]=	_jc_soot_tagkit_SourcePositionTag$instanceof_hash_bucket_89,
	[113]=	_jc_soot_tagkit_SourcePositionTag$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_tagkit_SourcePositionTag$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "soot/tagkit/PositionTag",	_JC_JLONG(0x4f112a0e13b029d9) },
	{ "soot/tagkit/Tag",	_JC_JLONG(0x145f73eb6621ab3a) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_tagkit_SourcePositionTag$vtype _jc_soot_tagkit_SourcePositionTag$type = {
    .type= {
	.name=			"soot/tagkit/SourcePositionTag",
	.superclass=		&_jc_soot_tagkit_PositionTag$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_soot_tagkit_SourcePositionTag$imethod_hash_table,
	.imethod_quick_table=	_jc_soot_tagkit_SourcePositionTag$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		17,
		.hash=			_JC_JLONG(0x50f5695cb4eac404),
		.source_file=		"SourcePositionTag.java",
		.instance_size=		sizeof(_jc_soot_tagkit_SourcePositionTag$refs) + sizeof(_jc_soot_tagkit_SourcePositionTag$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_soot_tagkit_SourcePositionTag$methods) / sizeof(*_jc_soot_tagkit_SourcePositionTag$methods),
		.methods=		_jc_soot_tagkit_SourcePositionTag$methods,
		.instanceof_hash_table=	_jc_soot_tagkit_SourcePositionTag$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_tagkit_SourcePositionTag$class_depends) / sizeof(*_jc_soot_tagkit_SourcePositionTag$class_depends),
		.class_depends=		_jc_soot_tagkit_SourcePositionTag$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_soot_tagkit_PositionTag$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_tagkit_PositionTag= {
	    .getEndOffset$4d0dd90be96a6f35=
		&_jc_soot_tagkit_PositionTag$method$getEndOffset$4d0dd90be96a6f35,
	    .getName$bec186f2ce7e1882=			// overridden
		&_jc_soot_tagkit_SourcePositionTag$method$getName$bec186f2ce7e1882,
	    .getStartOffset$2827f75ce05b8912=
		&_jc_soot_tagkit_PositionTag$method$getStartOffset$2827f75ce05b8912,
	    .getValue$824c7561d2f47329=
		&_jc_soot_tagkit_PositionTag$method$getValue$824c7561d2f47329,
	    .toString$7ea43b33b80a3070=
		&_jc_soot_tagkit_PositionTag$method$toString$7ea43b33b80a3070,
	},
	.soot_tagkit_SourcePositionTag= {
	    .getName$bec186f2ce7e1882=
		&_jc_soot_tagkit_SourcePositionTag$method$getName$bec186f2ce7e1882,
	},
    }
};

==> jc-1.4.5.tar.gz: soot/tagkit/SourcePositionTag.c <==
// public class soot.tagkit.SourcePositionTag

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 4f112a0e13b029d9 soot_tagkit_PositionTag
// @dep_class 50f5695cb4eac404 soot_tagkit_SourcePositionTag
// @dep_class 145f73eb6621ab3a soot_tagkit_Tag

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header soot_tagkit_SourcePositionTag
// @dep_header soot_tagkit_Tag

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "soot/tagkit/SourcePositionTag.h"
#include "soot/tagkit/Tag.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(int, int)
//

static _jc_linenum _jc_soot_tagkit_SourcePositionTag$linenum_table$_init$02b806c1c13eed5e[];

static const unsigned char _jc_soot_tagkit_SourcePositionTag$param_ptypes$_init$02b806c1c13eed5e[] = { 
_JC_TYPE_INT, _JC_TYPE_INT, _JC_TYPE_VOID };

static _jc_type *const _jc_soot_tagkit_SourcePositionTag$param_types$_init$02b806c1c13eed5e[] = {
	&_jc_int$prim$type,
	&_jc_int$prim$type
};

_jc_method _jc_soot_tagkit_SourcePositionTag$method_info$_init$02b806c1c13eed5e = {
	.name=			"<init>",
	.signature=		"(II)V",
	.class=			&_jc_soot_tagkit_SourcePositionTag$type,
	.param_types=		&_jc_soot_tagkit_SourcePositionTag$param_types$_init$02b806c1c13eed5e,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_tagkit_SourcePositionTag$param_ptypes$_init$02b806c1c13eed5e,
	.signature_hash=	_JC_JLONG(0x2b806c1c13eed5e),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_tagkit_SourcePositionTag$method$_init$02b806c1c13eed5e,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_tagkit_SourcePositionTag$linenum_table$_init$02b806c1c13eed5e
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_tagkit_SourcePositionTag, _init$02b806c1c13eed5e);

void _JC_JCNI_ATTR
_jc_soot_tagkit_SourcePositionTag$method$_init$02b806c1c13eed5e(_jc_env *const env, _jc_soot_tagkit_SourcePositionTag$object *this, jint param0, jint param1)
{
	jint i0;
	jint i1;
	struct _jc_soot_tagkit_SourcePositionTag$object *r0;

	r0 = this;
	i0 = param0;
	i1 = param1;
	_JC_PRIM_FIELD(env, r0, soot_tagkit_PositionTag, startOffset) = i0;
	_JC_PRIM_FIELD(env, r0, soot_tagkit_PositionTag, endOffset) = i1;
	_JC_LINE_NUMBER(6);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String getName()
//

static _jc_linenum _jc_soot_tagkit_SourcePositionTag$linenum_table$getName$bec186f2ce7e1882[];

static const unsigned char _jc_soot_tagkit_SourcePositionTag$param_ptypes$getName$bec186f2ce7e1882[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_tagkit_SourcePositionTag$method_info$getName$bec186f2ce7e1882 = {
	.name=			"getName",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_soot_tagkit_SourcePositionTag$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_soot_tagkit_SourcePositionTag$param_ptypes$getName$bec186f2ce7e1882,
	.signature_hash=	_JC_JLONG(0xbec186f2ce7e1882),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_tagkit_SourcePositionTag$method$getName$bec186f2ce7e1882,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_tagkit_SourcePositionTag$vtable, soot_tagkit_SourcePositionTag.getName$bec186f2ce7e1882) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_tagkit_SourcePositionTag$linenum_table$getName$bec186f2ce7e1882
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_tagkit_SourcePositionTag, getName$bec186f2ce7e1882);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_soot_tagkit_SourcePositionTag$method$getName$bec186f2ce7e1882(_jc_env *const env, _jc_soot_tagkit_SourcePositionTag$object *this)
{
	struct _jc_soot_tagkit_SourcePositionTag$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(10);				// 0
	return _JC_STRING(env, "SourcePositionTag");
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_tagkit_SourcePositionTag$methods[] = {
	&_jc_soot_tagkit_SourcePositionTag$method_info$_init$02b806c1c13eed5e,
	&_jc_soot_tagkit_SourcePositionTag$method_info$getName$bec186f2ce7e1882
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_soot_tagkit_SourcePositionTag$imethod_hash_bucket_2[] = {
	&_jc_soot_tagkit_SourcePositionTag$method_info$getName$bec186f2ce7e1882,
	_JC_NULL
};
static _jc_method *_jc_soot_tagkit_SourcePositionTag$imethod_hash_bucket_41[] = {
	&_jc_soot_tagkit_PositionTag$method_info$getValue$824c7561d2f47329,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_soot_tagkit_SourcePositionTag$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[2]=	_jc_soot_tagkit_SourcePositionTag$imethod_hash_bucket_2,
	[41]=	_jc_soot_tagkit_SourcePositionTag$imethod_hash_bucket_41
};

// Interface "quick" lookup hash table
static const void *_jc_soot_tagkit_SourcePositionTag$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[2]=	&_jc_soot_tagkit_SourcePositionTag$method$getName$bec186f2ce7e1882,
	[41]=	&_jc_soot_tagkit_PositionTag$method$getValue$824c7561d2f47329
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_tagkit_SourcePositionTag$instanceof_hash_bucket_4[] = {
	&_jc_soot_tagkit_SourcePositionTag$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_SourcePositionTag$instanceof_hash_bucket_58[] = {
	&_jc_soot_tagkit_Tag$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_SourcePositionTag$instanceof_hash_bucket_89[] = {
	&_jc_soot_tagkit_PositionTag$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_SourcePositionTag$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_tagkit_SourcePositionTag$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[4]=	_jc_soot_tagkit_SourcePositionTag$instanceof_hash_bucket_4,
	[58]=	_jc_soot_tagkit_SourcePositionTag$instanceof_hash_bucket_58,
	[89]=	_jc_soot_tagkit_SourcePositionTag$instanceof_hash_bucket_89,
	[101]=	_jc_soot_tagkit_SourcePositionTag$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_tagkit_SourcePositionTag$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "soot/tagkit/PositionTag",	_JC_JLONG(0x4f112a0e13b029d9) },
	{ "soot/tagkit/Tag",	_JC_JLONG(0x145f73eb6621ab3a) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_tagkit_SourcePositionTag$vtype _jc_soot_tagkit_SourcePositionTag$type = {
    .type= {
	.name=			"soot/tagkit/SourcePositionTag",
	.superclass=		&_jc_soot_tagkit_PositionTag$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_soot_tagkit_SourcePositionTag$imethod_hash_table,
	.imethod_quick_table=	_jc_soot_tagkit_SourcePositionTag$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		17,
		.hash=			_JC_JLONG(0x50f5695cb4eac404),
		.source_file=		"SourcePositionTag.java",
		.instance_size=		sizeof(_jc_soot_tagkit_SourcePositionTag$refs) + sizeof(_jc_soot_tagkit_SourcePositionTag$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_soot_tagkit_SourcePositionTag$methods) / sizeof(*_jc_soot_tagkit_SourcePositionTag$methods),
		.methods=		_jc_soot_tagkit_SourcePositionTag$methods,
		.instanceof_hash_table=	_jc_soot_tagkit_SourcePositionTag$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_tagkit_SourcePositionTag$class_depends) / sizeof(*_jc_soot_tagkit_SourcePositionTag$class_depends),
		.class_depends=		_jc_soot_tagkit_SourcePositionTag$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_soot_tagkit_PositionTag$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_tagkit_PositionTag= {
	    .getEndOffset$4d0dd90be96a6f35=
		&_jc_soot_tagkit_PositionTag$method$getEndOffset$4d0dd90be96a6f35,
	    .getName$bec186f2ce7e1882=			// overridden
		&_jc_soot_tagkit_SourcePositionTag$method$getName$bec186f2ce7e1882,
	    .getStartOffset$2827f75ce05b8912=
		&_jc_soot_tagkit_PositionTag$method$getStartOffset$2827f75ce05b8912,
	    .getValue$824c7561d2f47329=
		&_jc_soot_tagkit_PositionTag$method$getValue$824c7561d2f47329,
	    .toString$7ea43b33b80a3070=
		&_jc_soot_tagkit_PositionTag$method$toString$7ea43b33b80a3070,
	},
	.soot_tagkit_SourcePositionTag= {
	    .getName$bec186f2ce7e1882=
		&_jc_soot_tagkit_SourcePositionTag$method$getName$bec186f2ce7e1882,
	},
    }
};
